Option Explicit
'#############################################################################
'# 
'# PowerChute Network Shutdown v.2.2.3
'# Copyright (C)2008 American Power Conversion Corporation. 
'# All Rights Reserved.
'#
'# History:
'#   17Jan2008 Initial revision
'#
'#############################################################################

'#############################################################################
'# Grobal Constants
'#############################################################################
Const con_PCNS_ZIP = "pcns223.exe"
Const con_TITLE = "PowerChute Network Shutdown - Installation"
Const con_GROUP1 = "group1"
Const con_GROUP2 = "group2"
Const con_GROUP3 = "group3"
Const con_CFG_INSTANCE_NUMBER = "CFG_INSTANCE_NUMBER="
Const con_CFG_INSTALL_DIR = "CFG_INSTALL_DIR="
Const con_CFG_JAVA_DIR = "CFG_JAVA_DIR="

'#############################################################################
'# Grobal Variables
'#############################################################################
Dim sstrSrcDir
Dim sstrInstallDir
Dim sstrJavaDir
Dim sintInstance
Dim sbSilentMode

'#############################################################################
'# Functions
'#############################################################################
Sub CreateFolderRecursive (objFso, strFolder)
    Dim strParent
    strParent = objFso.GetParentFolderName(strFolder)
    If Not objFso.FolderExists(strParent) Then
        CreateFolderRecursive objFso, strParent
    End If
    objFso.CreateFolder(strFolder)
End Sub

Sub RunCommand (strCommand)
    Dim objExec, objShell
    Dim strLine

    Set objShell = WScript.CreateObject("WScript.Shell")
    Set objExec = objShell.Exec(strCommand)
    If Err.Number = 0 Then
        Do Until objExec.StdOut.AtEndOfStream
            strLine = objExec.StdOut.ReadLine
            WScript.StdOut.WriteLine strLine
        Loop
    Else
        WScript.StdOut.WriteLine "[Error]: " & Err.Description
    End If
    Set objExec = Nothing
    Set objShell = Nothing
End Sub

Sub PrintUsage ()
    WScript.Echo "Usage:" & vbCrLf _
        & " cscript " & WScript.ScriptName & " [/f <config file>] :  Silent install with configuration file." & vbCrLf _
        & " cscript " & WScript.ScriptName & " [/h|/H] : Print help."
    WScript.Quit
End Sub

Function IsX64 ()
    Dim strDir, strProgramFilesX86
    Dim objShell
    Set objShell = WScript.CreateObject("WScript.Shell")
    strProgramFilesX86 = "%ProgramFiles(x86)%"

    strDir = objShell.ExpandEnvironmentStrings(strProgramFilesX86)
    If (strDir = strProgramFilesX86) Then
        IsX64 = False
    Else
        IsX64 = True
    End If
    Set objShell = Nothing
End Function

Function GetProgramFiles ()
    Dim objShell
    Set objShell = WScript.CreateObject("WScript.Shell")
    If (IsX64() = True) Then
        GetProgramFiles = objShell.ExpandEnvironmentStrings("%ProgramFiles(x86)%")
    Else
        GetProgramFiles = objShell.ExpandEnvironmentStrings("%ProgramFiles%")
    End If
    Set objShell = Nothing
End Function

Sub CheckSilentConfigParameter (strSilentConfigFile, strCfg)
    Dim strLine, strTmp
    Dim intCount
    intCount = 0

    Dim objFso, objFile
    Set objFso = WScript.CreateObject("Scripting.FileSystemObject")
    If (objFso.FileExists(strSilentConfigFile) = true) Then
        Set objFile = objFso.OpenTextFile(strSilentConfigFile, 1)
    Else
        WScript.StdOut.WriteLine "[Error]: Invalid file name " & strSilentConfigFile
        CancelInstallation
    End If

    If (Err.Number = 0) Then
        Do Until objFile.AtEndOfStream
            strLine = objFile.ReadLine
            If (InStr(strLine, strCfg) = 1) Then
                intCount = intCount+1
            End If
        Loop
        objFile.Close
    End If

    If (intCount = 0) Then
        If (strCfg = con_CFG_INSTALL_DIR) Then
            sstrInstallDir = GetProgramFiles() & "\APC\"
            WScript.StdOut.WriteLine "CFG_INSTALL_DIR is not specified, PCNS is installed to the default directory " & sstrInstallDir
            WScript.StdOut.WriteBlankLines 1
        Else
            WScript.StdOut.WriteLine "[Error]: " & strCfg & " is not defined in " & strSilentConfigFile
            CancelInstallation
        End If
    ElseIf (intCount > 1) Then
        WScript.StdOut.WriteLine "[Error]: Too many " & strCfg & " in " & strSilentConfigFile
        CancelInstallation
    End If 
    Set objFso = Nothing
    Set objFile = Nothing
End Sub

Sub SetSilentConfig (strSilentConfigFile)
    Dim strLine, strTmp
    
    CheckSilentConfigParameter strSilentConfigFile, con_CFG_INSTANCE_NUMBER
    CheckSilentConfigParameter strSilentConfigFile, con_CFG_INSTALL_DIR
    CheckSilentConfigParameter strSilentConfigFile, con_CFG_JAVA_DIR
    sintInstance = 0
    
    Dim objFso, objFile
    Set objFso = WScript.CreateObject("Scripting.FileSystemObject")
    Set objFile = objFso.OpenTextFile(strSilentConfigFile, 1)

    If (Err.Number = 0) Then
        Do Until objFile.AtEndOfStream
            strLine = objFile.ReadLine
            If (InStr(strLine, con_CFG_INSTANCE_NUMBER) = 1) Then
                strTmp = Trim(Mid(strLine, Len(con_CFG_INSTANCE_NUMBER)+1))
                If (IsNumeric(strTmp)) Then
                    sintInstance = CInt(strTmp)
                End If
                If (sintInstance < 1 or 3 < sintInstance) Then
                    WScript.StdOut.WriteLine "[Error]: CFG_INSTANCE_NUMBER=" & strTmp & " is invalid. It must be [1-3]"
                    CancelInstallation
                End If
            End If
            If (InStr(strLine, con_CFG_INSTALL_DIR) = 1) Then
                sstrInstallDir = Trim(Mid(strLine, Len(con_CFG_INSTALL_DIR)+1))
                If (Len(sstrInstallDir) = 0) Then
                    sstrInstallDir = GetProgramFiles() & "\APC\"
                Else
                    If (Len(sstrInstallDir) = 2 or objFso.FolderExists(Left(sstrInstallDir, 3)) = False) Then
                        WScript.StdOut.WriteLine "[Error]: CFG_INSTALL_DIR=" & sstrInstallDir & " is invalid"
                        CancelInstallation
                    End If
                    If (Right(sstrInstallDir, 1) <> "\") Then
                        sstrInstallDir = sstrInstallDir & "\"
                    End If 
                    If (Len(sstrInstallDir) = 3) Then
                        sstrInstallDir = sstrInstallDir & "APC\"
                    End If
                End If
            End If
            If (InStr(strLine, con_CFG_JAVA_DIR) = 1) Then
                sstrJavaDir = Trim(Mid(strLine, Len(con_CFG_JAVA_DIR)+1))
                If (Len(sstrJavaDir) = 0) Then
                    WScript.StdOut.WriteLine "[Error]: " & con_CFG_JAVA_DIR & " is not defined in " & strSilentConfigFile
                    CancelInstallation
                End If
                If (Right(sstrJavaDir, 1) <> "\") Then
                    sstrJavaDir = sstrJavaDir & "\"
                End If 
                Dim strJavaExe
                strJavaExe = sstrJavaDir & "bin\java.exe"
                If (objFso.FileExists(strJavaExe) <> true) Then
                    WScript.StdOut.WriteLine "[Error]: CFG_JAVA_DIR=" & sstrJavaDir & " is invalid, java.exe does not exist."
                    CancelInstallation
                End If
            End If
        Loop
        objFile.Close
    End If
    WScript.StdOut.WriteLine con_CFG_INSTANCE_NUMBER & sintInstance
    WScript.StdOut.WriteLine con_CFG_INSTALL_DIR & sstrInstallDir
    WScript.StdOut.WriteLine con_CFG_JAVA_DIR & sstrJavaDir
    WScript.StdOut.WriteLine
    Set objFso = Nothing
    Set objFile = Nothing
End Sub

Sub CheckSilentInstall ()
    Dim strSilentConfigFile
    If (WScript.Arguments.Count = 1 or WScript.Arguments.Count > 2) Then
        PrintUsage
    End If
    If (WScript.Arguments.Count = 2) Then
        ' Silent mode
        If (UCase(WScript.Arguments.Item(0)) = "/F") Then
            strSilentConfigFile = WScript.Arguments.Item(1)
            WScript.StdOut.WriteLine "Silent Installation. Configuration file: " & strSilentConfigFile
            sbSilentMode = True
            SetSilentConfig strSilentConfigFile
        Else
            PrintUsage
        End If
    Else
        ' Interactive mode
        sbSilentMode = False
    End If
End Sub

Sub CheckOS ()
    Dim strCurrentVersion, strProductName
    Dim bResult
    Dim objShell
    Set objShell = WScript.CreateObject("WScript.Shell")
    
    strCurrentVersion = objShell.RegRead("HKLM\SOFTWARE\Microsoft\Windows NT\CurrentVersion\CurrentVersion")
    strProductName = objShell.RegRead("HKLM\SOFTWARE\Microsoft\Windows NT\CurrentVersion\ProductName")
    WScript.StdOut.WriteLine "OS : " & strProductName
    bResult = False
    If (Left(strCurrentVersion, 2) = "6.") Then
         If (InStr(strProductName, "2008") > 0) Then
             bResult = True
         End If
    End If
    If (bResult <> True) Then
        WScript.StdOut.WriteLine strProductName & " is not supported."
        CancelInstallation
    End If
    Set objShell = Nothing
End Sub

Sub IsRootUser ()
    Dim strUserName, strComputerName, strUserDomain, strAdminPath, objAdminInfo
    Dim objNetwork, objAdminGroup
    Dim bResult
    
    Set objNetwork = CreateObject("Wscript.Network")
    strUserName = objNetwork.UserName
    strComputerName = objNetwork.ComputerName
    strAdminPath = "WinNT://" & strComputerName & "/Administrators,group"

    bResult = False
    Set objAdminGroup = GetObject(strAdminPath)
    If objAdminGroup.PropertyCount > 0 Then
        Dim strMem
        For Each strMem In objAdminGroup.Members
            If (strMem.Name = strUserName) Then
                bResult = True
            End If
        Next
    Else
        WScript.StdOut.WriteLine "[Error]: Connecting to the local Administrators group on " & strComputerName & " failed."
    End If
    If (bResult <> True) Then
        WScript.StdOut.WriteLine "[Error]: " & WScript.ScriptName & " must be run with administrator privileges!"
        CancelInstallation
    End If
    Set objNetwork = Nothing
    Set objAdminGroup = Nothing
End Sub

Function IsServiceInstalled (strServiceName)
    Dim strQuery
    Dim objServiceList
    strQuery = "SELECT * FROM Win32_Service" & _
            " WHERE Name = '" & strServiceName & "'"
    Set objServiceList = GetObject("winmgmts:").ExecQuery(strQuery)
    If (objServiceList.Count <> 1) Then
        IsServiceInstalled = False
    Else
        IsServiceInstalled = True
    End If
    Set objServiceList = Nothing
End Function

Sub IsPCNSInstalled ()
    Dim bResult
    bResult = IsServiceInstalled("PCNS")
    If (bResult <> True) Then
        bResult = IsServiceInstalled("PCNS1")
    End If
    If (bResult = True) Then
        WScript.StdOut.WriteLine "PowerChute Network Shutdown is already installed."
        CancelInstallation
    End If
End Sub

Sub IsPCBEInstalled ()
    Dim bResult
    bResult = IsServiceInstalled("APCPBEAgent")
    If (bResult <> True) Then
        bResult = IsServiceInstalled("APCPBEServer")
    End If
    If (bResult = True) Then
        WScript.StdOut.WriteLine "PowerChute Business Edition is installed. Please uninstall PCBE."
        CancelInstallation
    End If
End Sub

Sub SetInstanceNumber ()
    Dim strMsg, strInstance
    Dim bExit
    If (sbSilentMode <> True) Then
        strMsg = "Please enter the PCNS instance number [1|2|3] or press enter to use default value of 1:"
        bExit = false
        Do while bExit = false
            WScript.StdOut.WriteBlankLines 1
            WScript.StdOut.Write strMsg 
            
            strInstance = Trim(WScript.StdIn.ReadLine)
            If (Len(strInstance) = 0) Then
                sintInstance = 1
                bExit = True
            ElseIf (IsNumeric(strInstance)) Then
                sintInstance = CInt(strInstance)
                If (1 <= sintInstance and sintInstance <= 3) Then
                    bExit = True
                End If
            End If
            strMsg = "Invalid value." & "Please try again :"
        Loop 
    End If
    WScript.StdOut.WriteLine sintInstance & " PCNS instance(s) will be installed."
End Sub

Sub SetInstallDir ()
    Dim strMsg, strProgramFiles
    Dim bExit
    Dim objShell
    Set objFso = WScript.CreateObject("Scripting.FileSystemObject")
    If (sbSilentMode <> True) Then
        strProgramFiles = GetProgramFiles()
        strMsg = "Please enter the installation directory " & _
                 "or press enter to install to the default directory (" & strProgramFiles & "\APC\PowerChute):"
        bExit = false
        Do while bExit = false
            WScript.StdOut.WriteBlankLines 1
            WScript.StdOut.WriteLine strMsg 
            sstrInstallDir = Trim(WScript.StdIn.ReadLine)
            If (Len(sstrInstallDir) = 0) Then
                sstrInstallDir = strProgramFiles & "\APC"
            End If
            If (objFso.FolderExists(Left(sstrInstallDir, 3)) <> true) Then
                WScript.StdOut.WriteLine "Invalid path : " & sstrInstallDir
            Else
                If (Right(sstrInstallDir, 1) <> "\") Then
                    sstrInstallDir = sstrInstallDir & "\"
                End If
                If (Len(sstrInstallDir) = 3 ) Then
                    sstrInstallDir = sstrInstallDir & "APC\"
                End If
                WScript.StdOut.Write "Are you sure you want to install PCNS to "& sstrInstallDir & "PowerChute [Y|N]?:"
                If (UCase(Left(Trim(WScript.StdIn.ReadLine), 1)) = "Y") Then
                    If (objFso.FolderExists(sstrInstallDir & "PowerChute") = true) Then
                        WScript.StdOut.WriteBlankLines 1
                        WScript.StdOut.Write sstrInstallDir & "PowerChute is already exists. Do you want to use it [Y|N]?:"
                        If (UCase(Left(Trim(WScript.StdIn.ReadLine), 1)) = "Y") Then
                            bExit = True
                        End If
                    Else
                        ' Create install dir later
                        bExit = True
                    End If
                End If
            End If
        Loop
        If Err.Number <> 0 Then
            CancelInstallation
        End If
    Else
        WScript.StdOut.WriteLine "PCNS will be installed to " & sstrInstallDir & "PowerChute"
    End If
    If (objFso.FolderExists(sstrInstallDir) <> true) Then
        WScript.StdOut.WriteLine "Creating " & sstrInstallDir & " ..."
        CreateFolderRecursive objFso, sstrInstallDir
    End If
    Set objFso = Nothing
End Sub

Sub SetupJava ()
    Dim strMsg, strJreExe
    Dim bExit
    Dim objFso, objShell
    If (sbSilentMode <> True) Then
        Set objShell = WScript.CreateObject("WScript.Shell")
        Set objFso = WScript.CreateObject("Scripting.FileSystemObject")
        strMsg = "JRE is not bundled. Please enter your java directory (example: C:\Program Files\java\jre1.5.0_13):"
        bExit = false
        Do while bExit = false
            WScript.StdOut.WriteBlankLines 1
            WScript.StdOut.WriteLine strMsg 
            
            sstrJavaDir = Trim(WScript.StdIn.ReadLine)
            If (Len(sstrJavaDir) > 0 And Right(sstrJavaDir, 1) <> "\") Then
                sstrJavaDir = sstrJavaDir & "\"
            End If 

            If (objFso.FolderExists(Left(sstrJavaDir, 3)) <> true) Then
                WScript.StdOut.WriteLine "Invalid path : " & sstrJavaDir
            Else
                If (objFso.FolderExists(sstrJavaDir) = true) Then
                    strJreExe = sstrJavaDir & "bin\java.exe"
                    If (objFso.FileExists(strJreExe) = true) Then
                        objShell.Run Chr(34) & strJreExe & Chr(34) & " -version"
                        bExit = true
                    End If
                End If
                If bExit = true Then
                    WScript.StdOut.Write "Are you sure java directory is "& sstrJavaDir & " [Y|N]?:"
                    If (UCase(Left(Trim(WScript.StdIn.ReadLine), 1)) <> "Y") Then
                        bExit = false
                    End If
                Else
                    WScript.StdOut.WriteLine "Invalid path: " & sstrJavaDir 
                End If
            End If
        Loop 
        Set objFso = Nothing
        Set objShell = Nothing
    End If
    WScript.StdOut.WriteBlankLines 1
    WScript.StdOut.WriteLine "Java Directory : " & sstrJavaDir
End Sub

Sub ExtractPCNS ()
    Dim objFso, objShell
    Set objShell = WScript.CreateObject("WScript.Shell")
    Set objFso = WScript.CreateObject("Scripting.FileSystemObject")
  
    ' Copy pcns223.exe
    WScript.StdOut.WriteLine "Copying PCNS files ..."
    objFso.CopyFile con_PCNS_ZIP, sstrInstallDir
    If (Err.Number <> 0) Then
        CancelInstallation
    End If

    objShell.CurrentDirectory = sstrInstallDir
    'WScript.StdOut.WriteLine "Current directory is " & objShell.CurrentDirectory

    ' Extract PCNS
    WScript.StdOut.WriteLine "Extracting " & con_PCNS_ZIP & " ..."
    objShell.Run con_PCNS_ZIP
    WScript.StdOut.WriteLine "PCNS is extracted to " & sstrInstallDir
    WScript.Sleep(2000)
    objFso.DeleteFile con_PCNS_ZIP

    objShell.CurrentDirectory = sstrInstallDir & "PowerChute"

    If (sintInstance >= 2) Then
        CopyGroupDir con_GROUP2
        If (sintInstance >= 3) Then
            CopyGroupDir con_GROUP3
        End If
    End If
    Set objFso = Nothing
End Sub

Sub CopyGroupDir (strGroup)
    Dim objFso
    Set objFso = WScript.CreateObject("Scripting.FileSystemObject")

    WScript.StdOut.WriteLine "Copying " & strGroup & " ..."
    If (objFso.FolderExists(strGroup) <> True) Then
        objFSO.CreateFolder(strGroup)
    End If
    objFso.CopyFolder con_GROUP1, strGroup, True
    If Err.Number = 0 Then
        WScript.StdOut.WriteLine strGroup & " is created."
        objFso.DeleteFile strGroup & "\PCNSConfig.vbs"
    Else
        WScript.StdOut.WriteLine "[Error]: " & Err.Description
    End If
    Set objFso = Nothing
    Set objShell = Nothing
End Sub

Sub SetupRegistry ()
    Dim strRegKeyPCNS
    Dim objShell
    Set objShell = WScript.CreateObject("WScript.Shell")
    
    SetupGroupRegistry con_GROUP1, "PCNS1"
    If (sintInstance >= 2) Then
        SetupGroupRegistry con_GROUP2, "PCNS2"
        If (sintInstance >= 3) Then
            SetupGroupRegistry con_GROUP3, "PCNS3"
        End If
    End If

    ' Software
    If (IsX64() = True ) Then
        strRegKeyPCNS = "HKLM\SOFTWARE\Wow6432Node\APC\PowerChuteNetworkShutdown"
    Else
        strRegKeyPCNS = "HKLM\SOFTWARE\APC\PowerChuteNetworkShutdown"
    End If
    Const con_REG_VERSION = "Version"
    Const con_VERSION = "2.2.3"
    Const con_REG_IMAGE_PATH = "ImagePath"
    objShell.RegWrite strRegKeyPCNS & "\" & con_REG_VERSION, con_VERSION, "REG_SZ"
    objShell.RegWrite strRegKeyPCNS & "\" & con_REG_IMAGE_PATH, sstrInstallDir & "PowerChute", "REG_SZ"
    
    If Err.Number <> 0 Then
        CancelInstallation
    End If
    Set objShell = Nothing
End Sub

Sub SetupGroupRegistry (strGroup, strServiceName)
    Dim strAppDir, strRegRoot
    Dim objShell
    Dim objFso
    Set objShell = WScript.CreateObject("WScript.Shell")
    Set objFso = WScript.CreateObject("Scripting.FileSystemObject")

    strAppDir = sstrInstallDir + "PowerChute\" & strGroup
    objShell.CurrentDirectory = strAppDir
    ' Check Apprication dir
    If (objFso.FileExists("pcns.exe") = true) Then
        ' Install pcns.exe as service
        objShell.Run "pcns.exe -install"
        If (Err.Number <> 0) Then
            CancelInstallation
        End If
        WScript.Sleep(2000)
        
        ' Service 
        Const con_REG_KEY_SERVICE = "HKLM\SYSTEM\CurrentControlSet\Services"
        Const con_REG_DESCRIPTION = "Description"
        Const con_REG_TYPE = "Type"
        Const con_REG_KEY_PARAMETERS = "Parameters"
        Const con_REG_APP_DIR = "AppDirectory"
        Const con_REG_APPLICATION = "Application"
        Const con_REG_APP_PARAMETERS = "AppParameters"
        Const con_REG_PARAMETERS = " -Xrs -cp .\lib\jetty-6.0.0.jar;.\lib\jetty-util-6.0.0.jar;.\lib\servlet-api-2.5-6.0.0.jar;.\lib\collections.jar;.\lib\jsdk.jar;.\lib\m11.jar;.\comp\ds.jar;.\comp\AAOL.jar;.\comp\CommandFileRunner.jar;.\comp\EventLogger.jar;.\comp\Notifier.jar;.\comp\Omaha.jar;.\comp\PacketRepeater.jar;.\comp\PowerSourceAggregator.jar;.\comp\PSAggregator.jar;.\comp\RunTimeVerifier.jar;.\comp\Shutdowner.jar;.\comp\StdPowerSource.jar;.\comp\WebServer.jar;.\comp\shutdownerlets\OSShutdownerlet.jar com.apcc.m11.arch.application.Application"
        Const con_REG_SERVICE_DESCRIPTION="Manages uninterruptible power supplies and provides support for graceful, unattended shutdowns in the case of specified power conditions."

        strRegRoot = con_REG_KEY_SERVICE & "\" & strServiceName & "\"
        objShell.RegWrite strRegRoot & con_REG_Description, con_REG_SERVICE_DESCRIPTION, "REG_SZ"
        objShell.RegWrite strRegRoot & con_REG_TYPE, 272, "REG_DWORD"
        
        strRegRoot = con_REG_KEY_SERVICE & "\" & strServiceName & "\" & con_REG_KEY_PARAMETERS & "\" 
        objShell.RegWrite strRegRoot & con_REG_APP_DIR, strAppDir, "REG_SZ"
        objShell.RegWrite strRegRoot & con_REG_APPLICATION, sstrJavaDir & "bin\java.exe", "REG_SZ"
        objShell.RegWrite strRegRoot & con_REG_APP_PARAMETERS, con_REG_PARAMETERS, "REG_SZ"

        WScript.StdOut.WriteLine "PCNS " & strGroup & " service is added."
    End If

    If (Err.Number <> 0) Then
        CancelInstallation
    End If
    Set objShell = Nothing
End Sub

Sub AddPCNSFirewallRule (strProtocol, strPortNum)
    Dim strRule, strName
    strName = Chr(34) & "PCNS " & strProtocol & strPortNum & Chr(34)
    WScript.StdOut.WriteLine " " & strName
    
    strRule = "netsh advfirewall firewall add rule" _
              & " name=" &  strName _
              & " dir=in action=allow" _
              & " protocol=" & strProtocol _
              & " localport=" & strPortNum
    RunCommand strRule

    If (Err.Number <> 0) Then
        WScript.StdOut.WriteLine "[Error]: " & Err.Description
    End If
End Sub

Sub AddFirewallRule ()
    WScript.StdOut.WriteBlankLines 1
    WScript.StdOut.WriteLine "Adding firewall rules ..."
    AddPCNSFirewallRule "UDP", "3052"
    AddPCNSFirewallRule "TCP", "3052"
    AddPCNSFirewallRule "TCP", "6547"
    If (sintInstance >= 2) Then
        AddPCNSFirewallRule "TCP", "2161"
        AddPCNSFirewallRule "TCP", "6548"
        If (sintInstance >= 3) Then
            AddPCNSFirewallRule "TCP", "2260"
            AddPCNSFirewallRule "TCP", "6549"
        End If
    End If
End Sub

Sub CancelInstallation ()
    WScript.StdOut.WriteLine ""
    If Err.Number <> 0 Then
        WScript.StdOut.WriteLine "[Error]: " & Err.Description
    End If
    WScript.StdOut.WriteLine "Installation canceled." & vbCrLf
    WScript.Quit
End Sub
'#############################################################################
'# Main routine
'#############################################################################

'Check CScript
If UCase(Right(WScript.FullName, 11)) = "WSCRIPT.EXE" Then
    PrintUsage
End If

Dim objShell
Set objShell = WScript.CreateObject("WScript.Shell")
' Set src dir
sstrSrcDir = objShell.CurrentDirectory
'WScript.StdOut.WriteLine "Current directory : " & sstrSrcDir

'# Check zipped install file
Dim objFso
Set objFso = WScript.CreateObject("Scripting.FileSystemObject")

If (objFso.FileExists(con_PCNS_ZIP) <> True) Then
    WScript.StdOut.WriteLine "Can't find " & con_PCNS_ZIP
    WScript.Quit
End If

' Print Banner
WScript.StdOut.WriteLine "------------------------------------------------------------------"
WScript.StdOut.WriteLine "     PowerChute Network Shutdown v.2.2.3 Installation Script"
WScript.StdOut.WriteLine "     Copyright American Power Conversion Corporation. 2007"
WScript.StdOut.WriteLine "------------------------------------------------------------------"
WScript.StdOut.WriteLine ""

' Check silent install
CheckSilentInstall

' Check OS type
CheckOS

' Check root account
IsRootUser

' Check installed applications
IsPCBEInstalled
IsPCNSInstalled

' Set number of PCNS instance
SetInstanceNumber

' Set Install dir
SetInstallDir

' Setup java
SetupJava

If (sbSilentMode <> True) Then
    WScript.StdOut.WriteBlankLines 1
    WScript.StdOut.Write "Are you sure you want to install PowerChute Network Shutdown [Y|N]?:"
    If (UCase(Left(Trim(WScript.StdIn.ReadLine), 1)) <> "Y") Then
        CancelInstallation
    End If
End If

' Extract PCNS files
ExtractPCNS

' Setup Registry
SetupRegistry

' Add PCNS firewall rule
AddFirewallRule

' Back to src directory
Set objShell = WScript.CreateObject("WScript.Shell")
objShell.CurrentDirectory = sstrSrcDir
Set objShell = Nothing

WScript.StdOut.WriteLine
WScript.StdOut.WriteLine "Completed."
WScript.StdOut.WriteLine
WScript.StdOut.WriteLine "Please run the PCNSConfig.vbs script located within the PCNS installation directory to complete the installation."
WScript.StdOut.WriteLine

'### EOF###